*==========================================================
* set up
*==========================================================
clear
set more off
macro drop _all
set scheme lean1 // plotplain s2mono s1color s1mono lean1

cap cd "C:/Users/Neo/Desktop/relocation/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* start logging
*==========================================================
log close _all
log using "$results/table_2.log", replace

*==========================================================
* read data
*==========================================================
use "$data/data_2016_model.dta", clear

*==========================================================
* ologit model
*==========================================================
** demographics
ologit dv hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople i.id_county
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_2.doc", replace label stats(coef) ctitle(Logit1) ///
	dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
	addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

** household characteristics
ologit dv hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople ///
	householdsize income_log yr16lvstockvalue_log landarea i.id_county
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_2.doc", append label stats(coef) ctitle(Logit2) ///
	dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
	addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

** community characteristics
ologit dv hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople ///
	householdsize income_log yr16lvstockvalue_log landarea ///
	i.runningwtr i.eletric yr16dis2pvrd yr16dis2mkt yr16dis2elescl yr16dis2midscl ///
	yr16dis2hscl friend vsttimes i.id_county
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_2.doc", append label stats(coef) ctitle(Logit3) ///
	dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
	addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

*==========================================================
* multilevel model: three-level
*==========================================================
** demographics
meologit dv hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople ///
	|| id_province: || id_county:
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_2.doc", append label stats(coef) ctitle(MLM1) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(AIC, `aic', BIC, `bic')

** household characteristics
meologit dv hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople ///
	householdsize income_log yr16lvstockvalue_log landarea ///
	|| id_province: || id_county:
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_2.doc", append label stats(coef) ctitle(MLM2) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(AIC, `aic', BIC, `bic')

** community characteristics
meologit dv hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople ///
	householdsize income_log yr16lvstockvalue_log landarea ///
	i.runningwtr i.eletric yr16dis2pvrd yr16dis2mkt yr16dis2elescl yr16dis2midscl ///
	yr16dis2hscl friend vsttimes ///
	|| id_province: || id_county:
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_2.doc", append label stats(coef) ctitle(MLM3) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(AIC, `aic', BIC, `bic')

*==========================================================
* end logging
*==========================================================
log close _all

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA


*=========================== END ===========================

