*==========================================================
* set up
*==========================================================
clear
set more off
macro drop _all
set scheme lean1 // plotplain s2mono s1color s1mono lean1

cap cd "C:/Users/Neo/Desktop/relocation/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* start logging
*==========================================================
log close _all
log using "$results/table_3.log", replace

// *==========================================================
// * prepare panel data
// *==========================================================
// *================================================
// * prepare data 2017
// *================================================
// *** read and merge willingness
// use "$data/2017final.dta", clear
// des, s
// merge 1:1 id using "$data/2016willingness.dta"
// tab _merge
// keep if _merge == 3
// drop _merge
// compare willingness will_cat3
// drop if yr16willingness == 0
// sum

// *** convert Yuan and Mu to Dollar and Hectare and log-transformation
// gen inc = income / 7.03
// gen livestock = yr17lvstockvalue / 7.03
// gen land_orig = yr17landarea_origin * 0.0667
// gen land_dest = yr17landarea_new * 0.0667

// gen inc_log = log(inc)
// replace inc_log = 0 if inc_log == .
// gen livestock_log = log(livestock)
// replace livestock_log = 0 if livestock_log == .

// rename yr17householdsize hhsize
// rename friend_origin friend_orig
// rename friend_new friend_dest
// rename house_satisfaction apt_happy

// keep hhage familytype hhsize hhgender hhmar hanpeople hhmidsch ///
// 	inc* livestock* land_orig land_dest leftbehind distance ///
// 	friend_orig friend_dest apt_happy ///
// 	id y id_county will_cat*
// gen year = 2017
// tempfile panel_data_2017
// save `panel_data_2017'

// *================================================
// * prepare data 2019
// *================================================
// *** read and merge willingness
// use "$data/2019final.dta", clear
// des, s
// merge 1:1 id using "$data/2016willingness.dta"
// tab _merge
// keep if _merge == 3
// drop _merge
// compare willingness will_cat3
// drop if yr16willingness == 0
// sum LandOrigin and FriendNew has -1

// *** get rid of -1
// bysort id_zirancun: egen meanlandarea1=mean(yr18landarea_origin)
// replace yr18landarea_origin=meanlandarea1 if yr18landarea_origin==-1
// sum yr18landarea_origin

// bysort id_zirancun: egen meanfriendnew1=mean(friend_new)
// replace friend_new=meanfriendnew1 if friend_new==-1
// sum friend_new
// des, s

// *** distance / 2
// capture gen distance = rtntime / 2

// *** convert Yuan and Mu to Dollar and Hectare and log-transformation
// gen inc = totalinc / 6.91
// gen livestock = lvstockvalue / 6.91
// gen land_orig = yr18landarea_origin * 0.0667
// gen land_dest = yr18landarea_new * 0.0667

// gen inc_log = log(inc)
// replace inc_log = 0 if inc_log == .
// gen livestock_log = log(livestock)
// replace livestock_log = 0 if livestock_log == .

// rename householdsize hhsize
// rename friend_origin friend_orig
// rename friend_new friend_dest
// rename house_satisfaction apt_happy

// keep hhage hhgender hhmidsch hhmar hanpeople familytype hhsize ///
// 	inc* livestock* land_orig land_dest leftbehind ///
// 	friend_orig friend_dest apt_happy dist ///
// 	id y id_county will_cat*
// gen year = 2019
// tempfile panel_data_2019
// save `panel_data_2019'

// *================================================
// * check data 2017 and 2019 and append to panel data
// *================================================
// use `panel_data_2017', clear
// append using `panel_data_2019'

// egen idn = group(id)
// gen id_province = substr(id, 1, 2)
// order id idn id_* y year hhage hhgender hhmidsch hhmar hanpeople familytype hhsize inc* ///
// 	livestock* land_orig land_dest leftbehind friend_dest friend_orig apt_happy distance will*
// drop income
// nmissing
// compress
// save "$data/panel_2017_2019.dta", replace

*==========================================================
* model
*==========================================================
*================================================
* read and setup panel data
*================================================
use "$data/panel_2017_2019.dta", clear
nmissing
xtset idn year

*================================================
* pooled OLS
*================================================
** demographic
ologit y hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople i.id_county i.year
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_3.doc", replace label stats(coef) ctitle(POLS1) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

** household characteristics
ologit y hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople hhsize ///
	inc_log livestock_log land_orig land_dest i.leftbehind friend_dest friend_orig i.id_county i.year
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_3.doc", append label stats(coef) ctitle(POLS2) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

** community characteristics
ologit y hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople hhsize ///
	inc_log livestock_log land_orig land_dest i.leftbehind friend_dest friend_orig ///
	i.will_cat5 apt_happy distance i.id_county i.year
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_3.doc", append label stats(coef) ctitle(POLS3) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

*================================================
* three-level model
*================================================
** demographic
meologit y hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople ///
  || id_province: || id_county:
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_3.doc", append label stats(coef) ctitle(MLM1) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(AIC, `aic', BIC, `bic')

** household characteristics
meologit y hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople hhsize ///
  inc_log livestock_log land_orig land_dest i.leftbehind friend_dest friend_orig ///
  || id_province: || id_county:
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_3.doc", append label stats(coef) ctitle(MLM2) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(AIC, `aic', BIC, `bic')

** community characteristics
meologit y hhage i.hhgender i.hhmidsch i.hhmar i.hanpeople hhsize ///
	inc_log livestock_log land_orig land_dest i.leftbehind friend_dest friend_orig ///
	i.will_cat5 apt_happy distance i.year || id_province: || id_county:
estat icc
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_3.doc", append label stats(coef) ctitle(MLM3) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(AIC, `aic', BIC, `bic')

*==========================================================
* end logging
*==========================================================
cd "$results"
local txtfiles: dir . files "*.txt"
foreach txt of local txtfiles {
  erase `txt'
}
log close _all

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA


*=========================== END ===========================

