*==========================================================
* set up
*==========================================================
clear
set more off
macro drop _all
set scheme lean1 // plotplain s2mono s1color s1mono lean1

cap cd "C:/Users/Neo/Desktop/relocation/"
global data = "$pwd" + "data"
global results = "$pwd" + "results"

*==========================================================
* start logging
*==========================================================
log close _all
log using "$results/table_4.log", replace

*==========================================================
* fixed-effects with different clustering options
*==========================================================
*================================================
* read and setup panel data
*================================================
use "$data/panel_2017_2019.dta", clear
nmissing
xtset idn year

*================================================
* recode gender from 1 (male) 2 (female) to 0 (male) 1 (female)
*================================================
gen gdr = 0 if hhgender == 1
replace gdr = 1 if hhgender == 2
tab gdr, mi
tab hhgender, mi
drop hhgender
rename gdr hhgender
label define hhgender 0 "Male" 1 "Female"
label values hhgender hhgender

*================================================
* check dummy vars values and labels
*================================================
* leftbehind hhgender hhmidsch hhmar hanpeople will_cat5
label list

*================================================
* create dummy year 2019 and interactions
*================================================
gen yr2019 = 1 if year == 2019
replace yr2019 = 0 if yr2019 == .

gen hhage_yr2019 = hhage * yr2019
gen hhgender_yr2019 = hhgender * yr2019
gen hhmidsch_yr2019 = hhmidsch * yr2019
gen hhmar_yr2019 = hhmar * yr2019
gen hanpeople_yr2019 = hanpeople * yr2019
gen livestock_log_yr2019 = livestock_log * yr2019
gen land_orig_yr2019 = land_orig * yr2019
gen land_dest_yr2019 = land_dest * yr2019
gen will_cat5_yr2019 = will_cat5 * yr2019
gen distance_yr2019 = distance * yr2019

*================================================
* panel-fixed effects, cluster-default
*================================================
feologit y hhage inc_log hhsize ib0.leftbehind friend_dest friend_orig apt_happy ///
	ib0.hhgender_yr2019 ib0.hhmidsch_yr2019 ib0.hhmar_yr2019 ///
	ib0.hanpeople_yr2019 livestock_log_yr2019 land_orig_yr2019 ///
	land_dest_yr2019 ib0.will_cat5_yr2019 distance_yr2019 ///
	i.id_county i.year
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_4.doc", replace label stats(coef se) ctitle(FE) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

*================================================
* panel-fixed effects, cluster-county
*================================================
feologit y hhage inc_log hhsize ib0.leftbehind friend_dest friend_orig apt_happy ///
	ib0.hhgender_yr2019 ib0.hhmidsch_yr2019 ib0.hhmar_yr2019 ///
	ib0.hanpeople_yr2019 livestock_log_yr2019 land_orig_yr2019 ///
	land_dest_yr2019 ib0.will_cat5_yr2019 distance_yr2019 ///
	i.id_county i.year, cluster(id_county)
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_4.doc", append label stats(coef se) ctitle(FE) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

*================================================
* panel-fixed effects, cluster-province
*================================================
feologit y hhage inc_log hhsize ib0.leftbehind friend_dest friend_orig apt_happy ///
	ib0.hhgender_yr2019 ib0.hhmidsch_yr2019 ib0.hhmar_yr2019 ///
	ib0.hanpeople_yr2019 livestock_log_yr2019 land_orig_yr2019 ///
	land_dest_yr2019 ib0.will_cat5_yr2019 distance_yr2019 ///
	i.id_county i.year, cluster(id_province)
estat ic
matrix ics = r(S)
local aic = ics[1, 5]
local bic = ics[1, 6]
outreg2 using "$results/table_4.doc", append label stats(coef se) ctitle(FE) ///
  dec(3) alpha(0.001, 0.01, 0.05) symbol(***, **, *) ///
  addstat(Pseudo R-squared, `e(r2_p)', AIC, `aic', BIC, `bic')

*==========================================================
* end logging
*==========================================================
cd "$results"
local txtfiles: dir . files "*.txt"
foreach txt of local txtfiles{
	erase `txt'
}
log close _all

// *==========================================================
// * clear memory and exit
// *==========================================================
// exit, clear STATA

*=========================== END ===========================

